==> upyble-0.0.1.tar.gz: upyble-0.0.1/setup.py <==
#!/usr/bin/env python3
# @Author: carlosgilgonzalez
# @Date:   2019-07-11T23:29:40+01:00
# @Last modified by:   carlosgilgonzalez
# @Last modified time: 2019-11-15T00:05:55+00:00

from setuptools import setup


def readme():
    with open('README.md', 'r', encoding="utf-8") as f:
        return f.read()


setup(name='upyble',
      version='0.0.1',
      description='Command line tool for Bluetooth Low Energy MicroPython devices',
      long_description=readme(),  # readme()
      long_description_content_type='text/markdown',
      url='http://github.com/Carglglz/upydev',
      author='Carlos Gil Gonzalez',
      author_email='carlosgilglez@gmail.com',
      classifiers=[
        'Development Status :: 3 - Alpha',
        'Environment :: Console',
        'Intended Audience :: Developers',
        'Intended Audience :: Science/Research',
        'Intended Audience :: Education',
        'Operating System :: MacOS :: MacOS X',
        'Operating System :: POSIX :: Linux',
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Topic :: System :: Monitoring',
        'Topic :: Scientific/Engineering',
        'Topic :: Software Development :: Embedded Systems',
        'Topic :: Terminals'
      ],
      license='MIT',
      packages=['upyble'],
      zip_safe=False,
      scripts=['upyble_dir/bin/upyble',
               'ble_repl_dir/bin/blerepl'],
      include_package_data=True,
      install_requires=['argcomplete', 'prompt_toolkit', 'requests',
                        'bleak', 'Pygments',
                        ])

==> upyble-0.0.2.tar.gz: upyble-0.0.2/setup.py <==
#!/usr/bin/env python3
# @Author: carlosgilgonzalez
# @Date:   2019-07-11T23:29:40+01:00
# @Last modified by:   carlosgilgonzalez
# @Last modified time: 2019-11-15T00:05:55+00:00

from setuptools import setup


def readme():
    with open('README.md', 'r', encoding="utf-8") as f:
        return f.read()


setup(name='upyble',
      version='0.0.2',
      description='Command line tool for Bluetooth Low Energy MicroPython devices',
      long_description=readme(),  # readme()
      long_description_content_type='text/markdown',
      url='http://github.com/Carglglz/upyble',
      author='Carlos Gil Gonzalez',
      author_email='carlosgilglez@gmail.com',
      classifiers=[
        'Development Status :: 3 - Alpha',
        'Environment :: Console',
        'Intended Audience :: Developers',
        'Intended Audience :: Science/Research',
        'Intended Audience :: Education',
        'Operating System :: MacOS :: MacOS X',
        'Operating System :: POSIX :: Linux',
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Topic :: System :: Monitoring',
        'Topic :: Scientific/Engineering',
        'Topic :: Software Development :: Embedded Systems',
        'Topic :: Terminals'
      ],
      license='MIT',
      packages=['upyble'],
      zip_safe=False,
      scripts=['upyble_dir/bin/upyble',
               'ble_repl_dir/bin/blerepl'],
      include_package_data=True,
      install_requires=['argcomplete', 'prompt_toolkit', 'requests',
                        'bleak', 'Pygments',
                        ])
